.. _pubchem:

.. raw:: html

    <br><br>

.. title:: PubChem


.. raw:: html

    <center><b>PUBCHEM</b></center><br>


.. _haldol2:


**HALDOL**

.. raw:: html

  <br>


.. image:: haldolpubchem.png
    :width: 100%

.. raw:: html

  <br><br>

.. _clozapine2:


**CLOZAPINE**


.. raw:: html

  <br>


.. image:: clozapinepubchem.png
    :width: 100%


.. raw:: html

  <br><br>

.. _zyprexa2:


**ZYPREXA**


.. raw:: html

  <br>

.. image:: zyprexapubchem.png
    :width: 100%

.. raw:: html

  <br><br>

.. _abilify2:


**ABILIFY**


.. raw:: html

  <br>

.. image:: abilifypubchem.png
     :width: 100%


.. raw:: html

    <br><br>